@@ -1,11 +1,12 @@
+from ast import Import
 import plotly.graph_objects as go
 
 import json
 from textwrap import dedent as d
 
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 from dash.dependencies import Input, Output, State
 
 import dash_bootstrap_components as dbc
@@ -16,7 +17,12 @@ import dash_bootstrap_components as dbc
 # external_stylesheets = [dbc.themes.GRID]
 external_stylesheets = [dbc.themes.BOOTSTRAP]
 
-from jupyter_dash import JupyterDash
+try:
+    from jupyter_dash import JupyterDash
+except ImportError:
+    print('jupyter_dash required: install using "conda install -c plotly conda install -c plotly jupyter-dash"')
+    sys.exit()
+    
 app = JupyterDash(__name__, external_stylesheets=external_stylesheets)
 # app = dash.Dash(__name__, external_stylesheets=external_stylesheets)
 
@@ -171,7 +177,7 @@ layout = html.Div(
                                                         # """), ),                    
                                                     ], width=3
                                                 ),                                                                                                                                                                                                        
-                                            ], justify="between", align="end", style={'padding': 3} #no_gutters=True, 
+                                            ], justify="between", align="end", style={'padding': 3} 
                                         ),
                                         dcc.Graph(id='arg-figure',
                                                 clear_on_unhover=True,
@@ -227,7 +233,8 @@ layout = html.Div(
                         ),            
                     ], width=4, 
                 ),        
-            ], no_gutters=True
+            ], 
+            className="g-0"
         ),
 
         dbc.Row(
@@ -295,7 +302,8 @@ layout = html.Div(
                         ),
                     ], width=6, align='start',
                 ),
-            ], no_gutters=True, 
+            ],
+            className="g-0"
         ),
     ], style={'padding': 20}
 )
@@ -532,6 +540,8 @@ def update_seq_slider(jsonified_data):
         nodes = []
     breakpoints = get_breakpoints(nodes)
     marks = dict((b*1000, str(i+1)) for i, b in enumerate(breakpoints))
+    if not marks:
+        marks = None
     return 0, 1000, [0, 1000], marks
 
 
